<?php

/*------------------------------------------------------------------------------
** File:        CloudKVSDB.php
** Class:       CloudKVSDB
** Description: DB Module equivalent - CloudKVS_Server
** Version:     0.1
** Updated:     16.08.2019
** Author:      Toky Olivier RAZANAKOTONARIVO
** Homepage:    www.soinala-studio.com 
**------------------------------------------------------------------------------ */

require_once( 'lib/MysqliDB/MysqliDB.php' );
require_once('B4XSerializator.php');

class CloudKVSDB {
	protected $db;
	protected $ser;
	
	public function __construct($host, $username, $password, $dbname) {
		$this->db = new MysqliDb($host, $username, $password, $dbname);
		$ser = new B4XSerializator(false);
	}
	
	function AddItem($item) {
		$fields = $item->Fields;
		$this->db->where ("user", $fields['UserField']);
		$id = $this->db->getValue ('data','max(id)');
		$id = ($id) ? $id + 1 : 1;
		if ($item->Fields['TimeField']<time()-30) {
			$ret = $this->db->rawQuery("SELECT * FROM data WHERE user = ? AND `key` = ?", array($fields['UserField'], $fields['KeyField']));
			if ($ret) {
				$ct = $ret['time'];
				if ($ct > $item->Fields['TimeField']) {
					$item->Fields['ValueField'] = $ret['value'];
					$item->Fields['TimeField'] = $ct;
				}
			}
		}
		$data = array (
			'user' => $item->Fields['UserField'],
			'key' => $item->Fields['KeyField'],
			'value' => $item->Fields['ValueField'],
			'id' => $id,
			'time' => min($item->Fields['TimeField'], time())
		);
		$updateColumns = Array ('value', 'id', 'time');
		$this->db->onDuplicate($updateColumns);
		$this->db->insert('data', $data);
	}
	
	function GetUserItems($user, $lastId) {
		$items = array();
		$this->db->where ('user', $user)->where ('id', $lastId, '>');
		$ret = $this->db->get('data', null);
		foreach ($ret as $r) {
			$data = array (
				'UserField' => $user,
				'KeyField' => $r['key'],
				'ValueField' => new B4XByteArray($r['value']),
				'IdField' => $r['id'],
				'TimeField' => $r['time']
			);
			$item = new B4XType('Item', $data);
			$items[] = $item;
		}
		return $items;
	}
	
	function DeleteUser($user) {
		$this->db->where ('user', $user);
		return $this->db->delete('data');
	}
}
